@@ -73,7 +73,7 @@ extern "C" {
 #endif
 
 #define FI_MAJOR_VERSION 2
-#define FI_MINOR_VERSION 0
+#define FI_MINOR_VERSION 2
 #define FI_REVISION_VERSION 0
 
 /* Removing these breaks the build for some apps.
@@ -156,9 +156,11 @@ typedef struct fid *fid_t;
 #define FI_COMMIT_COMPLETE	(1ULL << 30)
 #define FI_MATCH_COMPLETE	(1ULL << 31)
 
+#define FI_RESCAN		(1ULL << 35)
 #define FI_PEER_TRANSFER	(1ULL << 36)
 /* #define FI_MR_DMABUF		(1ULL << 40) */
 #define FI_AV_USER_ID		(1ULL << 41)
+#define FI_FIREWALL_ADDR	(1ULL << 42)
 #define FI_PEER			(1ULL << 43)
 /* #define FI_XPU_TRIGGER		(1ULL << 44) */
 
@@ -689,6 +691,7 @@ enum {
 	FI_GET_VAL,		/* struct fi_fid_var */
 	FI_SET_VAL,		/* struct fi_fid_var */
 	FI_EXPORT_FID,		/* struct fi_fid_export */
+	FI_GET_FD, 		/* int */
 };
 
 static inline int fi_control(struct fid *fid, int command, void *arg)
